/**************************************************************************//**
 * @file     main.c
 * @brief    Main program body
 * @version  V1.6.0
 * @date     31-Dec-2021
 *
 * @note
 * Copyright (C) 2021 Spintrol Limited Corporation. All rights reserved.
 *
 * @attention
 * THIS SOFTWARE JUST PROVIDES CUSTOMERS WITH CODING INFORMATION REGARDING
 * THEIR PRODUCTS, WHICH AIMS AT SAVING TIME FOR THEM. SPINTROL SHALL NOT BE
 * LIABLE FOR THE USE OF THE SOFTWARE. SPINTROL DOES NOT GUARANTEE THE
 * CORRECTNESS OF THIS SOFTWARE AND RESERVES THE RIGHT TO MODIFY THE SOFTWARE
 * WITHOUT NOTIFICATION.
 *
 ******************************************************************************/

#include"spc2168.h"
#include<stdio.h>
#include<stdlib.h>

#define                   DEBUG_INFO                        1                         /*debug infomation flag*/
#define                   T_BUFFER_SIZE                     128                       /*data size of recieve and tansmit*/
#define                   DataWidth_8bit                    8                         /*data width size of SSP*/
#define                   SSPBaudrate_3M                    3000000                  /*SSP baudrate*/

uint32_t                  gu32BuffSize                      = T_BUFFER_SIZE;
uint32_t                  gau32TxBuf[T_BUFFER_SIZE];
uint32_t                  gau32RxBuf[T_BUFFER_SIZE];
uint32_t                  gau32Buf[T_BUFFER_SIZE];

void SSP_TxRx(void)
{
    printf("Master Tx data...\n");
    gau32TxBuf[0] = 0x30;
    gau32TxBuf[1] = 0x3F31;
    gau32TxBuf[2] = 0x32;
    gau32TxBuf[3] = 0x33;
    SSP_Send(SSP, gau32TxBuf, 4);
}


 /*************************************************************************************************************************
 *
 * @brief      In this case, Master sent data to slave .
 *
 *************************************************************************************************************************/


int main()
{
  FLASH_WALLOW();
  FLASH_SetTiming(200000000);
  /* Disable flash write access after flash operation had done */
  FLASH_WDIS();

  CLOCK_InitWithRCO(CLOCK_HCLK_200MHZ);

  Delay_Init();

  /*
   * Init the UART
   *
   * 1.Set the GPIO34/35 as UART FUNC
   *
   * 2.Enable the UART CLK
   *
   * 3.Set the rest para
   */
  GPIO_SetPinChannel(GPIO_44,GPIO44_UART_TXD);
  GPIO_SetPinChannel(GPIO_45,GPIO45_UART_RXD);
  CLOCK_EnableModule(UART_MODULE);
  UART_Init(UART,38400);

  /* Set GPIOs as SSP function */
  GPIO_SetPinChannel(GPIO_38,GPIO38_SPI_SCLK);
  GPIO_SetPinChannel(GPIO_39,GPIO39_SPI_SFRM);
  GPIO_SetPinChannel(GPIO_40,GPIO40_SPI_MOSI);
  GPIO_SetPinChannel(GPIO_41,GPIO41_SPI_MISO);

  /* Set Output Strength(for high speed) */
  GPIO_SetOutStrength(GPIO_38, GPIO_OUT_STRENGTH_20MA);
  GPIO_SetOutStrength(GPIO_39, GPIO_OUT_STRENGTH_20MA);
  GPIO_SetOutStrength(GPIO_40, GPIO_OUT_STRENGTH_20MA);
  GPIO_SetOutStrength(GPIO_41, GPIO_OUT_STRENGTH_20MA);

  /*
   * Init SSP Baud Rate, Frame Format
   * 1) Set master mode
   * 2) Set frame data 8-bits width
   * 3) Set transfer speed 30Mbps
   * 4) Set pin SFRM active low
   * 5) Set SCLK Polarity: SCLK is low when bus idle
   * 6) Set SCLK Phase: sample data on SCLK rising edge
   */
  SSP_Init(SSP, SSP_MASTER_MODE, DataWidth_8bit, SSPBaudrate_3M, SSP_FRM_ACTIVE_LOW, 
                          SSP_CLK_IDLE_LOW,SSP_SEND_ON_FALLING_EDGE);
                          
  /* Disable FIFO Packed Mode */
  SSP_DisableFIFOPackMode(SSP);

  /* Enable SSP */
  SSP_Enable(SSP);
  
  /* SSP Master Tx/Rx datum */
  SSP_TxRx();

  while(1)
  {
    
  }
}
